betty.project.extension.privatizer package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.privatizer package

## Module contents

Privatize people and associated data by determining if they are likely to be alive.

final class betty.project.extension.privatizer.Privatizer

  Bases: `ShorthandPluginBase`, `Extension`

  Extend the Betty Application with privatization features.

  register_event_handlers(registry: EventHandlerRegistry) → None

    Register event handlers with the project.